/*
 *  KCHMSetupDialog_impl.cpp
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 */
 
#include "kchmsetupdialog_impl.h"
#include "kchmsetupdialog_impl.moc"
#if defined(USE_KDE)
#include <tdeapplication.h>
#endif

KCHMSetupDialog_impl::KCHMSetupDialog_impl(TQWidget* parent, const char* name, bool modal, WFlags fl)
    : KCHMSetupDialog(parent, name, modal, fl)
{
}

void KCHMSetupDialog_impl::slotShowHelp()
{
#if defined(USE_KDE)
  kapp->invokeHelp();
#endif
}
